==> cryptwentyone-0.3.0.tar.gz: cryptwentyone-0.3.0/README.md <==
Cryptwentyone\[0.3.0\]
=============

Cryptwentyone is a simple python package that provides simple cryptographic and hashing functions. They are written in
pure python and C, so you can take a look at the python code if you want to learn about the algorithms or use the
compiled C code if you want to use the functions in your own programs and have a good performance.

**_The Package is under development and is not yet ready for use._** Support me
by [donating](https://github.com/MPCodeWriter21/cryptwentyone/blob/master/DONATE.md) or by contributing(Fork the repo.
Add your code. Submit a pull request.) or just give this repository a star.

Available Features
------------------

+ Python Implementation of MD5 hashing algorithm
+ Python Implementation of SHA1 hashing algorithm
+ Python Implementation of SHA2(SHA256) hashing algorithm
+ Any idea? Feel free to [open an issue](https://github.com/MPCodeWriter21/cryptwentyone/issues) or submit a pull request.

About
-----
Author: CodeWriter21 (Mehrad Pooryoussof)

GitHub: [MPCodeWriter21](https://github.com/MPCodeWriter21)

Telegram Channel: [@CodeWriter21](https://t.me/CodeWriter21)

Aparat Channel: [CodeWriter21](https://www.aparat.com/CodeWriter21)

### License

![License](https://img.shields.io/github/license/MPCodeWriter21/cryptwentyone)

[apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

### Donate

In order to support this project you can donate some crypto of your choice 8D

[Donate Addresses](https://github.com/MPCodeWriter21/cryptwentyone/blob/master/DONATE.md)

Or if you can't, give [this project](https://github.com/MPCodeWriter21/cryptwentyone) a star on GitHub :)

==> cryptwentyone-0.5.0.tar.gz: cryptwentyone-0.5.0/README.md <==
Cryptwentyone\[0.5.0\]
=============

Cryptwentyone is a simple python package that provides simple cryptographic and hashing functions. They are written in
pure python and C, so you can take a look at the python code if you want to learn about the algorithms or use the
compiled C code if you want to use the functions in your own programs and have a good performance.

**_The Package is under development and is not yet ready for use._** Support me
by [donating](https://github.com/MPCodeWriter21/cryptwentyone/blob/master/DONATE.md) or by contributing(Fork the repo.
Add your code. Submit a pull request.) or just give this repository a star.

Available Features
------------------

+ Python Implementation of MD5 hashing algorithm
+ Python Implementation of SHA1 hashing algorithm
+ Python Implementation of SHA2(SHA224, SHA256, SHA384, SHA512) hashing algorithm
+ Any idea? Feel free to [open an issue](https://github.com/MPCodeWriter21/cryptwentyone/issues) or submit a pull
  request.

Installation
------------

Well, this is a python package so the first thing you need is python.

If you don't have python installed, please visit [Python.org](https://python.org) and install the latest version of
python.

Then you can install cryptwentyone using pip module:

```shell
# Use this command to download the latest version from pypi.org and install it automatically
python -m pip install log21 -U

# OR
# Download the release file from GitHub: https://github.com/MPCodeWriter21/cryptwentyone/releases
# And install it using this command
pip install cryptwentyone-x.x.x.tar.gz
```

Or you can clone [the repository](https://github.com/MPCodeWriter21/cryptwentyone) and run:

```shell
python setup.py install
```

About
-----
Author: CodeWriter21 (Mehrad Pooryoussof)

GitHub: [MPCodeWriter21](https://github.com/MPCodeWriter21)

Telegram Channel: [@CodeWriter21](https://t.me/CodeWriter21)

Aparat Channel: [CodeWriter21](https://www.aparat.com/CodeWriter21)

### License

![License](https://img.shields.io/github/license/MPCodeWriter21/cryptwentyone)

[apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

### Donate

In order to support this project you can donate some crypto of your choice 8D

[Donate Addresses](https://github.com/MPCodeWriter21/cryptwentyone/blob/master/DONATE.md)

Or if you can't, give [this project](https://github.com/MPCodeWriter21/cryptwentyone) a star on GitHub :)
